==> gorilla-notebook-0.4.10.jar: gorilla-repl-client/js/cljs/cljs-runtime/pinkgorilla.kernel.shadowcljs.js <==
goog.provide('pinkgorilla.kernel.shadowcljs');
goog.require('cljs.core');
goog.require('taoensso.timbre');
goog.require('cljs.core.async');
goog.require('pinkgorilla.kernel.clojure');
goog.require('pinkgorilla.kernel.cljs_helper');
pinkgorilla.kernel.shadowcljs.init_BANG_ = (function pinkgorilla$kernel$shadowcljs$init_BANG_(config){
pinkgorilla.kernel.clojure.init_BANG_(config);

return taoensso.timbre._log_BANG_.cljs$core$IFn$_invoke$arity$10(taoensso.timbre._STAR_config_STAR_,new cljs.core.Keyword(null,"info","info",-317069002),"pinkgorilla.kernel.shadowcljs","/tmp/form-init9210512555929219670.clj",14,new cljs.core.Keyword(null,"p","p",151049309),new cljs.core.Keyword(null,"auto","auto",-566279492),(new cljs.core.Delay((function (){
return new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, ["shadow cljs kernel init done"], null);
}),null)),null,1667477223);
});
pinkgorilla.kernel.shadowcljs.eval_BANG_ = (function pinkgorilla$kernel$shadowcljs$eval_BANG_(segment_id,snippet){
var c__42129__auto___49618 = cljs.core.async.chan.cljs$core$IFn$_invoke$arity$1((1));
cljs.core.async.impl.dispatch.run((function (){
var f__42130__auto__ = (function (){var switch__42062__auto__ = (function (state_49610){
var state_val_49611 = (state_49610[(1)]);
if((state_val_49611 === (1))){
var inst_49604 = cljs.core.PersistentHashMap.EMPTY;
var inst_49605 = pinkgorilla.kernel.clojure.the_eval.cljs$core$IFn$_invoke$arity$2(snippet,inst_49604);
var state_49610__$1 = state_49610;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_49610__$1,(2),inst_49605);
} else {
if((state_val_49611 === (2))){
var inst_49607 = (state_49610[(2)]);
var inst_49608 = pinkgorilla.kernel.cljs_helper.send_result_eval(segment_id,inst_49607);
var state_49610__$1 = state_49610;
return cljs.core.async.impl.ioc_helpers.return_chan(state_49610__$1,inst_49608);
} else {
return null;
}
}
});
return (function() {
var pinkgorilla$kernel$shadowcljs$eval_BANG__$_state_machine__42063__auto__ = null;
var pinkgorilla$kernel$shadowcljs$eval_BANG__$_state_machine__42063__auto____0 = (function (){
var statearr_49612 = [null,null,null,null,null,null,null];
(statearr_49612[(0)] = pinkgorilla$kernel$shadowcljs$eval_BANG__$_state_machine__42063__auto__);

(statearr_49612[(1)] = (1));

return statearr_49612;
});
var pinkgorilla$kernel$shadowcljs$eval_BANG__$_state_machine__42063__auto____1 = (function (state_49610){
while(true){
var ret_value__42064__auto__ = (function (){try{while(true){
var result__42065__auto__ = switch__42062__auto__(state_49610);
if(cljs.core.keyword_identical_QMARK_(result__42065__auto__,new cljs.core.Keyword(null,"recur","recur",-437573268))){
continue;
} else {
return result__42065__auto__;
}
break;
}
}catch (e49613){if((e49613 instanceof Object)){
var ex__42066__auto__ = e49613;
var statearr_49615_49621 = state_49610;
(statearr_49615_49621[(5)] = ex__42066__auto__);


cljs.core.async.impl.ioc_helpers.process_exception(state_49610);

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
throw e49613;

}
}})();
if(cljs.core.keyword_identical_QMARK_(ret_value__42064__auto__,new cljs.core.Keyword(null,"recur","recur",-437573268))){
var G__49622 = state_49610;
state_49610 = G__49622;
continue;
} else {
return ret_value__42064__auto__;
}
break;
}
});
pinkgorilla$kernel$shadowcljs$eval_BANG__$_state_machine__42063__auto__ = function(state_49610){
switch(arguments.length){
case 0:
return pinkgorilla$kernel$shadowcljs$eval_BANG__$_state_machine__42063__auto____0.call(this);
case 1:
return pinkgorilla$kernel$shadowcljs$eval_BANG__$_state_machine__42063__auto____1.call(this,state_49610);
}
throw(new Error('Invalid arity: ' + arguments.length));
};
pinkgorilla$kernel$shadowcljs$eval_BANG__$_state_machine__42063__auto__.cljs$core$IFn$_invoke$arity$0 = pinkgorilla$kernel$shadowcljs$eval_BANG__$_state_machine__42063__auto____0;
pinkgorilla$kernel$shadowcljs$eval_BANG__$_state_machine__42063__auto__.cljs$core$IFn$_invoke$arity$1 = pinkgorilla$kernel$shadowcljs$eval_BANG__$_state_machine__42063__auto____1;
return pinkgorilla$kernel$shadowcljs$eval_BANG__$_state_machine__42063__auto__;
})()
})();
var state__42131__auto__ = (function (){var statearr_49617 = (f__42130__auto__.cljs$core$IFn$_invoke$arity$0 ? f__42130__auto__.cljs$core$IFn$_invoke$arity$0() : f__42130__auto__.call(null));
(statearr_49617[(6)] = c__42129__auto___49618);

return statearr_49617;
})();
return cljs.core.async.impl.ioc_helpers.run_state_machine_wrapped(state__42131__auto__);
}));


return null;
});

//# sourceMappingURL=pinkgorilla.kernel.shadowcljs.js.map

==> gorilla-notebook-0.4.11.jar: gorilla-repl-client/js/cljs/cljs-runtime/pinkgorilla.kernel.shadowcljs.js <==
goog.provide('pinkgorilla.kernel.shadowcljs');
goog.require('cljs.core');
goog.require('taoensso.timbre');
goog.require('cljs.core.async');
goog.require('pinkgorilla.kernel.clojure');
goog.require('pinkgorilla.kernel.cljs_helper');
pinkgorilla.kernel.shadowcljs.init_BANG_ = (function pinkgorilla$kernel$shadowcljs$init_BANG_(config){
pinkgorilla.kernel.clojure.init_BANG_(config);

return taoensso.timbre._log_BANG_.cljs$core$IFn$_invoke$arity$10(taoensso.timbre._STAR_config_STAR_,new cljs.core.Keyword(null,"info","info",-317069002),"pinkgorilla.kernel.shadowcljs","/tmp/form-init1011153544949464259.clj",14,new cljs.core.Keyword(null,"p","p",151049309),new cljs.core.Keyword(null,"auto","auto",-566279492),(new cljs.core.Delay((function (){
return new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, ["shadow cljs kernel init done"], null);
}),null)),null,-1634015294);
});
pinkgorilla.kernel.shadowcljs.eval_BANG_ = (function pinkgorilla$kernel$shadowcljs$eval_BANG_(segment_id,snippet){
var c__42130__auto___49620 = cljs.core.async.chan.cljs$core$IFn$_invoke$arity$1((1));
cljs.core.async.impl.dispatch.run((function (){
var f__42131__auto__ = (function (){var switch__42062__auto__ = (function (state_49610){
var state_val_49611 = (state_49610[(1)]);
if((state_val_49611 === (1))){
var inst_49604 = cljs.core.PersistentHashMap.EMPTY;
var inst_49605 = pinkgorilla.kernel.clojure.the_eval.cljs$core$IFn$_invoke$arity$2(snippet,inst_49604);
var state_49610__$1 = state_49610;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_49610__$1,(2),inst_49605);
} else {
if((state_val_49611 === (2))){
var inst_49607 = (state_49610[(2)]);
var inst_49608 = pinkgorilla.kernel.cljs_helper.send_result_eval(segment_id,inst_49607);
var state_49610__$1 = state_49610;
return cljs.core.async.impl.ioc_helpers.return_chan(state_49610__$1,inst_49608);
} else {
return null;
}
}
});
return (function() {
var pinkgorilla$kernel$shadowcljs$eval_BANG__$_state_machine__42063__auto__ = null;
var pinkgorilla$kernel$shadowcljs$eval_BANG__$_state_machine__42063__auto____0 = (function (){
var statearr_49614 = [null,null,null,null,null,null,null];
(statearr_49614[(0)] = pinkgorilla$kernel$shadowcljs$eval_BANG__$_state_machine__42063__auto__);

(statearr_49614[(1)] = (1));

return statearr_49614;
});
var pinkgorilla$kernel$shadowcljs$eval_BANG__$_state_machine__42063__auto____1 = (function (state_49610){
while(true){
var ret_value__42064__auto__ = (function (){try{while(true){
var result__42065__auto__ = switch__42062__auto__(state_49610);
if(cljs.core.keyword_identical_QMARK_(result__42065__auto__,new cljs.core.Keyword(null,"recur","recur",-437573268))){
continue;
} else {
return result__42065__auto__;
}
break;
}
}catch (e49615){if((e49615 instanceof Object)){
var ex__42066__auto__ = e49615;
var statearr_49616_49621 = state_49610;
(statearr_49616_49621[(5)] = ex__42066__auto__);


cljs.core.async.impl.ioc_helpers.process_exception(state_49610);

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
throw e49615;

}
}})();
if(cljs.core.keyword_identical_QMARK_(ret_value__42064__auto__,new cljs.core.Keyword(null,"recur","recur",-437573268))){
var G__49622 = state_49610;
state_49610 = G__49622;
continue;
} else {
return ret_value__42064__auto__;
}
break;
}
});
pinkgorilla$kernel$shadowcljs$eval_BANG__$_state_machine__42063__auto__ = function(state_49610){
switch(arguments.length){
case 0:
return pinkgorilla$kernel$shadowcljs$eval_BANG__$_state_machine__42063__auto____0.call(this);
case 1:
return pinkgorilla$kernel$shadowcljs$eval_BANG__$_state_machine__42063__auto____1.call(this,state_49610);
}
throw(new Error('Invalid arity: ' + arguments.length));
};
pinkgorilla$kernel$shadowcljs$eval_BANG__$_state_machine__42063__auto__.cljs$core$IFn$_invoke$arity$0 = pinkgorilla$kernel$shadowcljs$eval_BANG__$_state_machine__42063__auto____0;
pinkgorilla$kernel$shadowcljs$eval_BANG__$_state_machine__42063__auto__.cljs$core$IFn$_invoke$arity$1 = pinkgorilla$kernel$shadowcljs$eval_BANG__$_state_machine__42063__auto____1;
return pinkgorilla$kernel$shadowcljs$eval_BANG__$_state_machine__42063__auto__;
})()
})();
var state__42132__auto__ = (function (){var statearr_49617 = (f__42131__auto__.cljs$core$IFn$_invoke$arity$0 ? f__42131__auto__.cljs$core$IFn$_invoke$arity$0() : f__42131__auto__.call(null));
(statearr_49617[(6)] = c__42130__auto___49620);

return statearr_49617;
})();
return cljs.core.async.impl.ioc_helpers.run_state_machine_wrapped(state__42132__auto__);
}));


return null;
});

//# sourceMappingURL=pinkgorilla.kernel.shadowcljs.js.map
